# StoredObjects

 This object is needed to save, process and transfer data about University objects for 
 the **Publications Activity Module**.

 Objects used in this module:
 - Publication - stores bibliographic data about a publication (title, published date, authors, citations, identifiers in databases)
 - Author - stores data about a person with publications (names in databases, affiliations, publications)
 - Department - stores information about department name and list of employees in it
 - University - stores list of departments
